# ETC JupyterLab Telemetry Coursera

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/educational-technology-collective/etc_jupyterlab_telemetry_coursera/main?urlpath=lab)

A JupyterLab telemetry extension that logs telemetry events to a AWS S3 Bucket.

## Requirements

* JupyterLab >= 3.0
* ETC JupyterLab Telemetry Extension (`etc-jupyterlab-telemetry-extension`)

## Dependencies

* etc_jupyterlab_telemetry_extension

This extension requires the ETC JupyterLab Telemetry Extension (EJTE). EJTE provides the JupyterLab events that are consumed by this extension.

`etc_jupyterlab_telemetry_extension` is included in the `install_requires` list in `setup.py`.  `etc_jupyterlab_telemetry_extension` will be installed as a dependecy when you install this extension.

## Configuration

The AWS endpoint that is used for storing telemetry data is configurable.  The configuration file must contain the URL, the name of the S3 bucket, and the path where the telemetry objects will be saved.  The configuration file should be placed in one of the config directories given by jupyter --paths.  It must be named `etc_jupyterlab_telemetry_coursera.json`.

This is an example of a valid JSON configuration file:

```json
{
  "url": "https://telemetry.mentoracademy.org",
  "bucket": "telemetry-edtech-labs-si-umich-edu",
  "path": "dev/telemetry"
}
```

## Install

To install the extension:

```bash
pip install git+https://github.com/educational-technology-collective/etc_jupyterlab_telemetry_coursera.git
```

## Uninstall

To remove the extension, execute:

```bash
pip uninstall etc_jupyterlab_telemetry_coursera
```

## Troubleshoot

If you are seeing the frontend extension, but it is not working, check
that the server extension is enabled:

```bash
jupyter server extension list
```

If the server extension is installed and enabled, but you are not seeing
the frontend extension, check the frontend extension is installed:

```bash
jupyter labextension list
```
## Contributing

### Development install

Note: You will need NodeJS to build the extension package.

The `jlpm` command is JupyterLab's pinned version of
[yarn](https://yarnpkg.com/) that is installed with JupyterLab. You may use
`yarn` or `npm` in lieu of `jlpm` below.

```bash
# Clone the repo to your local environment
# Change directory to the etc_jupyterlab_telemetry_coursera directory
# Install package in development mode
pip install -e .
# Link your development version of the extension with JupyterLab
jupyter labextension develop . --overwrite
# Server extension must be manually installed in develop mode
jupyter server extension enable etc_jupyterlab_telemetry_coursera
# Rebuild extension Typescript source after making changes
jlpm run build
```

You can watch the source directory and run JupyterLab at the same time in different terminals to watch for changes in the extension's source and automatically rebuild the extension.

```bash
# Watch the source directory in one terminal, automatically rebuilding when needed
jlpm run watch
# Run JupyterLab in another terminal
jupyter lab
```

With the watch command running, every saved change will immediately be built locally and available in your running JupyterLab. Refresh JupyterLab to load the change in your browser (you may need to wait several seconds for the extension to be rebuilt).

By default, the `jlpm run build` command generates the source maps for this extension to make it easier to debug using the browser dev tools. To also generate source maps for the JupyterLab core extensions, you can run the following command:

```bash
jupyter lab build --minimize=False
```

### Development uninstall

```bash
# Server extension must be manually disabled in develop mode
jupyter server extension disable etc_jupyterlab_telemetry_coursera
pip uninstall etc_jupyterlab_telemetry_coursera
```

In development mode, you will also need to remove the symlink created by `jupyter labextension develop`
command. To find its location, you can run `jupyter labextension list` to figure out where the `labextensions`
folder is located. Then you can remove the symlink named `@educational-technology-collective/etc_jupyterlab_telemetry_coursera` within that folder.
